# -*- Mode: perl; indent-tabs-mode: nil -*-
#
# The contents of this file are subject to the Mozilla Public
# License Version 1.1 (the "License"); you may not use this file
# except in compliance with the License. You may obtain a copy of
# the License at http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS
# IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
# implied. See the License for the specific language governing
# rights and limitations under the License.
#
# The Original Code is the Bugzilla Launchpad Plugin.
#
# The Initial Developer of the Original Code is Canonical Ltd.
# Portions created by Canonical are Copyright (C) 2008 Canonical Ltd.
# All Rights Reserved.
#
# Contributor(s): Elliotte Martin <emartin@everythingsolved.com>

use strict;
use warnings;
use Bugzilla;
use Bugzilla::Group;
use Bugzilla::User;
use Bugzilla::Util qw(validate_email_syntax);

use constant LAUNCHPAD_REGISTRATION_URL => 'FIXME';

my $dbh = Bugzilla->dbh;
my $silent = Bugzilla->hook_args->{'silent'};

# create launchpad_api group.
my $launchpad_api = new Bugzilla::Group({name => 'launchpad_api'});
if (!$launchpad_api) {
    $launchpad_api = Bugzilla::Group->create({
        name        => 'launchpad_api',
        description => 'Used by the Launchpad plugin',
        isbuggroup  => 0 });

    my $editbugs = new Bugzilla::Group({ name => 'editbugs' });
    $dbh->do('INSERT INTO group_group_map (grantor_id, member_id)
                   VALUES (?,?)', undef, $editbugs->id, $launchpad_api->id);
                   
    # admin group should not inherit launchpad_api 
    my $admin = new Bugzilla::Group({ name => 'admin' });
    $dbh->do('DELETE FROM group_group_map 
               WHERE grantor_id = ? AND member_id = ?',
                undef, $launchpad_api->id, $admin->id);
}


# Create Launchpad user

# First, determine what the user name will be.
my $emailregexp = Bugzilla->params->{'emailregexp'};

my $username = 'launchpad-bugzilla@launchpad.net';
if ( !validate_email_syntax($username) or Bugzilla->params->{'emailsuffix'}) {
   $username =  'launchpad-bugzilla';
}

if (!new Bugzilla::User({name => $username})) {
    print "Creating Launchpad user " . $username . "...\n" unless $silent;
    my $user = Bugzilla::User->create({ login_name    => $username,
                                        realname      => 'Launchpad.net',
                                        cryptpassword => '*' });

    my $group_insert = $dbh->prepare(
    'INSERT INTO user_group_map (user_id, group_id, isbless, grant_type)
           VALUES (?, ?, ?, ?)');

    # These are run in an eval so that we can ignore the error of somebody
    # already being granted these things.
    eval {
        $group_insert->execute($user->id, $launchpad_api->id, 0, GRANT_DIRECT);
    };

    print "\nThank you for installing the Launchpad plugin!\n",
          "Please go to ", LAUNCHPAD_REGISTRATION_URL,
          " to register your Bugzilla.\n\n";
}
